nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Lock

Struct Lock 

#[repr(transparent)]
pub struct Lock(pub u32);
Lock register allows locking to the current security level or unlocking by the lock holding level.

Tuple Fields

0: u32

Implementations

Source

impl Lock

pub const fn seclock(&self) -> Seclock

Write 1 to secure-lock this block (if running in a security state). Write 0 to unlock. If locked already, may only write if at same or higher security level as lock. Reads as: 0 if unlocked, else 1, 2, 3 to indicate security level it is locked at. NOTE: this and ID are the only readable registers if locked and current state is lower than lock level.

pub const fn set_seclock(&mut self, val: Seclock)

Write 1 to secure-lock this block (if running in a security state). Write 0 to unlock. If locked already, may only write if at same or higher security level as lock. Reads as: 0 if unlocked, else 1, 2, 3 to indicate security level it is locked at. NOTE: this and ID are the only readable registers if locked and current state is lower than lock level.

pub const fn pattern(&self) -> u16

Must write 0xA75 to change lock state. A75:Pattern needed to change bits 1:0

pub const fn set_pattern(&mut self, val: u16)

Must write 0xA75 to change lock state. A75:Pattern needed to change bits 1:0