#[repr(transparent)]pub struct Memctrl(pub u32);Expand description
Setup Master to access memory (if available)
Tuple Fields
0: u32Implementations
Sourceimpl Memctrl
impl Memctrl
Sourcepub const fn set_master(&mut self, val: Master)
pub const fn set_master(&mut self, val: Master)
Enables mastering.
Sourcepub const fn count(&self) -> u16
pub const fn count(&self) -> u16
Number of 512-bit (128-bit if AES, except 1st block which may include key and IV) blocks to copy starting at MEMADDR. This register will decrement after each block is copied, ending in 0. For Hash, the DIGEST interrupt will occur when it reaches 0. Fro AES, the DIGEST/OUTDATA interrupt will occur on ever block. If a bus error occurs, it will stop with this field set to the block that failed. 0:Done - nothing to process. 1 to 2K: Number of 512-bit (or 128bit) blocks to hash.
Sourcepub const fn set_count(&mut self, val: u16)
pub const fn set_count(&mut self, val: u16)
Number of 512-bit (128-bit if AES, except 1st block which may include key and IV) blocks to copy starting at MEMADDR. This register will decrement after each block is copied, ending in 0. For Hash, the DIGEST interrupt will occur when it reaches 0. Fro AES, the DIGEST/OUTDATA interrupt will occur on ever block. If a bus error occurs, it will stop with this field set to the block that failed. 0:Done - nothing to process. 1 to 2K: Number of 512-bit (or 128bit) blocks to hash.