nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

PrngOut

Struct PrngOut 

#[repr(transparent)]
pub struct PrngOut(pub u32);
PRNG software-accessable random output value

Tuple Fields

0: u32

Implementations

Source

impl PrngOut

pub const fn prng_out(&self) -> u32

Random output value from the PRNG. The PRNG output is disabled and this register is set to 0x00000000 when the AES is enabled.

pub const fn set_prng_out(&mut self, val: u32)

Random output value from the PRNG. The PRNG output is disabled and this register is set to 0x00000000 when the AES is enabled.