#[repr(transparent)]pub struct PrngOut(pub u32);Expand description
PRNG software-accessable random output value
Tuple Fields
0: u32Implementations
Sourceimpl PrngOut
impl PrngOut
Sourcepub const fn prng_out(&self) -> u32
pub const fn prng_out(&self) -> u32
Random output value from the PRNG. The PRNG output is disabled and this register is set to 0x00000000 when the AES is enabled.
Sourcepub const fn set_prng_out(&mut self, val: u32)
pub const fn set_prng_out(&mut self, val: u32)
Random output value from the PRNG. The PRNG output is disabled and this register is set to 0x00000000 when the AES is enabled.